@@ -637,10 +637,10 @@ class KubeflowPlugin:
             or transformer.get("latestReadyRevision"),
             "traffic_percentage": total_traffic or stable_traffic or 100,
             "has_canary": bool(has_canary),
-            "stable_revision": stable_revision,
-            "canary_revision": canary_revision,
-            "stable_traffic_percent": stable_traffic,
-            "canary_traffic_percent": canary_traffic,
+            "stable_revision": canary_revision,
+            "canary_revision": stable_revision,
+            "stable_traffic_percent": canary_traffic,
+            "canary_traffic_percent": stable_traffic,
         }
 
         return model_info
@@ -1260,11 +1260,11 @@ class KubeflowPlugin:
                 for data_product in data_products:
                     client_op = fl_client(
                         server_address=setup_task.output,
-                        local_data_connector=data_product.get("region"),
+                        local_data_connector=data_product.get("access_url"),
                         **client_kwargs,
                     ).after(setup_task)
 
-                    region = data_product.get("access_url")
+                    region = data_product.get("region")
                     # ← CHANGE: only add node selector if enforcement is enabled
                     if _node_enforce:
                         client_op.add_node_selector_constraint("region", region)
@@ -1279,7 +1279,7 @@ class KubeflowPlugin:
 
         # Decorate as a pipeline
         flpipeline = dsl.pipeline(
-            name="Federated Learning Pipeline", description="Auto-generated FL pipeline"
+            name="Federated Learning Pipeline for Dataspace", description="Auto-generated FL pipeline for Dataspace"
         )(fl_pipeline_func)
         return flpipeline
 
@@ -1695,11 +1695,11 @@ class KubeflowPlugin:
                     "While promotion/disable/update, must be between 0 and 100."
                 )
         else:
-            # First-time rollout → must be partial (1–99)
-            if not 1 <= canary_traffic_percent <= 99:
+            # First-time rollout → must be partial (1–100)
+            if not 1 <= canary_traffic_percent <= 100:
                 raise ValueError(
                     f"Invalid canary_traffic_percent={canary_traffic_percent}. "
-                    "For initial rollout, must be between 1 and 99."
+                    "For initial rollout, must be between 1 and 100."
                 )
 
         # If all checks pass
